Streaming Audio Pipeline
Asynchronous audio processing pipeline for streaming decode and resample. This eliminates the memory spike issue with 192kHz upsampling.
Structs
- Audio
Pipeline - Streaming audio pipeline that decodes and resamples in background
- Ring
Buffer - Simple ring buffer for audio data Uses monotonic counters (frames_written, frames_consumed) for clean overflow handling.
Enums
- Pipeline
Error - Error returned when constructing an
AudioPipeline. - Pipeline
Status - Status of the audio pipeline